@@ -13,9 +13,7 @@ import threading
 import ssl
 
 # TODO: $iothub/methods/POST/# is unnecessary in topics
-# TODO: on_settings does not work
-# TODO: restart method
-# TODO: async methods
+# TODO: on_settings does not work when not used
 # TODO: generate sas on reconnect
 
 
@@ -256,7 +254,7 @@ class Module:
         if not self.client:
             raise error("Client not initialized")
 
-        async def handler(c, u, message):
+        def handler(c, u, message):
             if asyncio.iscoroutinefunction(cb):
                 asyncio.create_task(cb(message.topic, message.payload))
             else:
